@@ -127,16 +127,14 @@ class MultiClassifier:
         cores: int = -1,
         random_state: int = randint(1000),
         verbose: bool = False,
-        imbalanced: bool = False,
         sampling: str = None,
-        strategy: str or float = "auto",
+        strategy: str or float = "auto"
     ) -> None:
 
         self.cores = cores
         self.random_state = random_state
         self.verbose = verbose
         self.sampling = sampling
-        self.imbalanced = imbalanced
         self.strategy = strategy
 
         self.oversampling_list = [
